from typing import Dict, List, Tuple, Union

import pandas as pd
import pytest
from sklearn.model_selection import train_test_split

from classification_model.config.core import config
from classification_model.preprocessing.data_manager import _load_raw_dataset


@pytest.fixture
def sample_input_data() -> Tuple[pd.DataFrame, pd.Series]:
    data = _load_raw_dataset()

    _, X_test, _, y_test = train_test_split(
        data.drop(config.model_config.target, axis=1),  # predictors
        data[config.model_config.target],  # target
        test_size=config.model_config.test_size,  # percentage of obs in test set
        random_state=config.model_config.seed,
    )  # seed to ensure reproducibility

    return X_test, y_test


@pytest.fixture
def get_titles() -> List[str]:
    return [
        "Mrs. Show",
        "Calvin Mr. Jhon",
        "The Miss. Claudia",
        "Unknown",
        "Master of puppets",
    ]



import typing as t

import pandas as pd

from classification_model import __version__ as _version
from classification_model.config.core import config
from classification_model.preprocessing.data_manager import load_pipeline
from classification_model.preprocessing.validation import validate_input

pipeline_file_name = f"{config.app_config.pipeline_save_file}{_version}.joblib"

titanic_pipe = load_pipeline(file_name=pipeline_file_name)


def make_prediction(input_data: t.Union[pd.DataFrame, dict]) -> dict:
    """Make predictions

    Args:
        input_data (t.Union[pd.DataFrame, dict]): Input data from either Pandas Dataframe
        or Dictionary

    Returns:
        dict: Dictionary containing the prediction
    """
    data = pd.DataFrame(input_data)
    data, errors = validate_input(data)
    results = {"predictions": None, "version": _version, "errors": errors}
    if not errors:
        predictions = titanic_pipe.predict(data)
        results = {"predictions": predictions, "version": _version, "errors": errors}
    return results



from config.core import config
from pipeline import titanic_pipe
from preprocessing.data_manager import load_dataset
from sklearn.model_selection import train_test_split

from classification_model.preprocessing.data_manager import save_pipeline


def run_training() -> None:
    data = load_dataset()

    X_train, _, y_train, _ = train_test_split(
        data[config.model_config.features],  # predictors
        data[config.model_config.target],  # target
        test_size=config.model_config.test_size,  # percentage of obs in test set
        random_state=config.model_config.seed,
    )  # seed to ensure reproducibility

    titanic_pipe.fit(X_train, y_train)

    save_pipeline(titanic_pipe)


if __name__ == "__main__":
    run_training()



import typing as t

import pandas as pd
from pydantic import BaseModel, ValidationError

from classification_model.config.core import config
from classification_model.preprocessing.data_manager import pre_pipeline_preparation


def validate_input(
    input_data: pd.DataFrame,
) -> t.Tuple[pd.DataFrame, t.Optional[t.Dict]]:
    errors = None
    pre_processed = None
    try:
        pre_processed = pre_pipeline_preparation(input_data)
        pre_processed = pre_processed[config.model_config.features]
        MultipleTitanicDataInputs(inputs=pre_processed.to_dict(orient="records"))
    except ValidationError as error:
        errors = error.errors()

    return pre_processed, errors


class TitanicInputSchema(BaseModel):
    pclass: int
    sex: str
    age: float
    sibsp: int
    parch: int
    fare: float
    cabin: str
    embarked: str
    name: t.Optional[str]
    ticket: t.Optional[str]
    boat: t.Optional[t.Union[str, int]]
    body: t.Optional[int]


class MultipleTitanicDataInputs(BaseModel):
    inputs: t.List[TitanicInputSchema]



from pathlib import Path
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

NAME = "tid-titanic-classification-model"
AUTHORS = "Edcalderin"
AUTHOR_EMAIL = "edcm.erick@gmail.com"
DESCRIPTION = "Example Titanic classification model package"
README = "README.md"
REQUIRES_PYTHON = ">=3.7"

HOMEPAGE = "https://github.com/edcalderin/deployment-titanic-classification-model"

PACKAGE_ROOT = Path(__file__).resolve().parent
PACKAGE_DIR = PACKAGE_ROOT/'classification_model'
REQUIREMENTS_DIR = PACKAGE_ROOT/'requirements'

about ={}
with open(PACKAGE_DIR/'VERSION') as file:
    about['__version__'] = file.read()

def list_requirements():
    with open(REQUIREMENTS_DIR/'requirements.txt') as file:
        return file.read().splitlines()

setup(
        name=NAME,
        version=about['__version__'],
        package_data={'classification_model': ['VERSION']},
        packages=find_packages(),
        description=DESCRIPTION,
        long_description=long_description,
        include_package_data=True,
        long_description_content_type="text/markdown",
        url=HOMEPAGE,
        author=AUTHORS,
        author_email=AUTHOR_EMAIL,
        license="MIT",
        python_requires=REQUIRES_PYTHON,
        classifiers=[
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.7",
        ],
        install_requires=list_requirements()
)